@@ -1,8 +1,10 @@
-import os
+import os.path as path
 
 
 def read_config(file_name):
-    config_file = os.path.abspath(file_name)
+    config_file = path.abspath(file_name)
+    if not path.isfile(config_file):
+        config_file = path.join(path.dirname(path.dirname(path.dirname(__file__))), file_name)
     config = {}
     with open(config_file, 'r') as f:
         for l in f.readlines():
